<?php
/*
	Plugin Name: Multi-Site Site List Shortcode
	Plugin URI: http://bit51.com/software/multi-site-site-list-shortcode/
	Description: Displays the site list with a shortcode for network installations.
	Version: 5.0
	Domain Path: /languages
	Author: Bit51.com
	Author URI: http://bit51.com
	License: GPLv2
	Copyright 2012  Bit51.com  (email : info@bit51.com)
*/

//define some paths right in the beginning
define('MSSLS_URL', plugin_dir_url(__FILE__));
define('MSSLS_PATH', plugin_dir_path(__FILE__));

//load the text domain
load_plugin_textdomain('multi_site_site_list_shortcode', false, dirname(plugin_basename( __FILE__ )) . '/languages');

//Require common Bit51 library
require_once(plugin_dir_path(__FILE__) . 'lib/bit51/bit51.php');

if (!class_exists('bit51_mssls')) {

	class bit51_mssls extends Bit51 {
	
		var $pluginversion 	= '5.0'; //current plugin version
	
		//important plugin information
		var $hook 				= 'multi_site_site_list_shortcode';
		var $pluginpath			= MSSLS_PATH;
		var $pluginbase			= 'multi-site-site-list-shortcode/multi-site-site-list-shortcode.php';
		var $pluginurl			= MSSLS_URL;
		var $pluginname			= 'Multi-Site Site List Shortcode';
		var $homepage			= 'http://bit51.com/software/multi-site-site-list-shortcode/';
		var $supportpage 		= 'http://forums.bit51.com/topic/multi-site-site-list-shortcode/';
		var $wppage 			= 'http://wordpress.org/extend/plugins/multi-site-site-list-shortcode/';
		var $accesslvl			= 'manage_network_options';
		var $paypalcode			= '7GDQDFENDBDAA';
		var $plugindata 		= 'bit51_mssls_data';
		var $primarysettings	= 'bit51_mssls';
		var $settings			= array(
			'bit51_mssls_options' => array(
				'bit51_mssls' => array(
					'callback' => 'mssls_val_options',
					'sortby' => '0',
					'openin' => '0',
					'excluded' => array()
				)
			)
		);

		/**
		 * Register the shortcode in instantiation 
		 */
		function __construct() {
			add_shortcode('site-list', array(&$this, 'display_site_list'));
		}
		
		/**
		 * Create site list
		 */
		function display_site_list() {
			global $wpdb;
			global $table_prefix;
			$output = '';
			
			//this is a workaround for lack of settings api with multi-site
			$options = $wpdb->get_results('SELECT option_value FROM ' . $wpdb->base_prefix . 'options WHERE option_name IN (\'' . $this->primarysettings . '\') ORDER BY option_name DESC');
			
			//convert options to array so we can use it like normal
			$options = unserialize($options[0]->option_value);
			
			//get blog list
			$blogs = $wpdb->get_col("SELECT blog_id FROM $wpdb->blogs WHERE public = '1' AND archived = '0' AND mature = '0' AND spam = '0' ORDER BY blog_id DESC");
			
			//make sure there are blogs
			if ($blogs) {
			
				$output .= '<div id="mssls"><ul>'; //assign a div to make styling easier
				$siteArray = array(); //initial array of sites to display
				
				foreach ($blogs as $blog) {
					if ($blog == '1') { //get blog options from the right table (blog 1 needs a special tablename)
						$table =  $wpdb->base_prefix . 'options';
					} else {
						$table = $wpdb->base_prefix . $blog . '_options';
					}
					
					if (is_array($options['excluded'])) {//get array of excluded blog id's
						$excluded = $options['excluded']; 
					} else {
						$excluded = unserialize($options['excluded']);
					}
						
					$sitedetails = $wpdb->get_results('SELECT option_value FROM ' . $table . ' WHERE option_name IN (\'siteurl\',\'blogname\') ORDER BY option_name DESC'); //get blog details
					
					if($sitedetails && !in_array($blog, $excluded)) { //if the blog exists and isn't on the exclusion list add it to array
						if ($options['sortby'] == 0) { //proper array construction depending on sort
							$siteArray[$sitedetails[1]->option_value]['url'] = $sitedetails[0]->option_value;
							$siteArray[$sitedetails[1]->option_value]['id'] = $blog;
						} else {
							$siteArray[$blog]['url'] = $sitedetails[0]->option_value;
							$siteArray[$blog]['title'] = $sitedetails[1]->option_value;
						}
					}
				}
				
				ksort($siteArray); //sort array
				
			}
			
			//create link target if necessary
			if ($options['openin'] == 0) {
				$target = ' target="_blank" ';
			} else {
				$target = ' ';
			}
			
			//add sites to output string
			foreach ($siteArray as $site => $value) {
				if ($options['sortby'] == 0) {
					$output .= '<li><a href="' .  $value['url'] . '"' . $target  . '>' . $site . '</a></li>';
				} else {
					$output .= '<li><a href="' .  $value['url'] . '"' . $target  . '>' . $value['title'] . '</a></li>';
				}		
			}
			
			return $output . '</ul></div>';
			
		}
	}
}

//create plugin object
new bit51_mssls();

//require admin page
require_once(plugin_dir_path(__FILE__) . 'inc/admin.php');

//require setup information
require_once(plugin_dir_path(__FILE__) . 'inc/setup.php');
register_activation_hook( __FILE__, array('mssls_setup', 'on_activate'));
register_deactivation_hook( __FILE__, array('mssls_setup', 'on_deactivate'));
register_uninstall_hook( __FILE__, array('mssls_setup', 'on_uninstall'));
